format property

FutureOr<Out> Function(List<(Param, Log)> entries, List<(Param, Log)> retryBuffer) format
final

Transforms a batch of parameter-log entries into an Out object.

Entries added to the retry buffer during formatting are excluded from the batch passed to output and retried with the next batch.

Implementation

final FutureOr<Out> Function(
  List<(Param, Log)> entries,
  List<(Param, Log)> retryBuffer,
) format;