handle method
Processes a single log event with its bound parameter.
Events are processed strictly sequentially: the next event is not handled until the future returned by this method completes.
Implementation
@override
FutureOr<void> handle(Param param, Log log) => switch (format(param, log)) {
final Future<Out> future => future.then((out) => output(param, out)),
final Out out => output(param, out),
};