LogBox class final

Mixed-in types

Constructors

LogBox(Log log, LogTheme theme, List<String> lines, {LogConstraints constraints = const LogConstraints.unlimited(), LogTextAlign textAlign = LogTextAlign.left, LogVerticalAlign verticalAlign = LogVerticalAlign.top, String? verticalFiller, bool showEllipsis = true, String? debugName})
factory
LogBox.empty({String? debugName})
LogBox.fromText(Log log, LogTheme theme, String text, {required int? maxLines, String? verticalFiller, LogConstraints constraints = const LogConstraints.unlimited(), LogTextAlign textAlign = LogTextAlign.left, LogVerticalAlign verticalAlign = LogVerticalAlign.top, String? debugName})
factory
LogBox.raw(int width, List<String> lines, {String? verticalFiller, LogVerticalAlign verticalAlign = LogVerticalAlign.top, String? debugName})

Properties

debugName String?
final
hashCode int
The hash code for this object.
no setterinherited
lines List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalAlign LogVerticalAlign
final
verticalFiller String?
final
width int
final

Methods

applyHeight(int linesCount) → void
collectLoggableData(LoggableData data) → void
Метод должен заполнить data описанием исследуемого класса.
override
logClassInfo() LoggableData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited