LogStyles class final

Mixed-in types

Constructors

LogStyles({required Style verbose, required Style debug, required Style info, required Style warning, required Style error, required Style critical})
const
LogStyles.only(Style style, {Style? verbose, Style? debug, Style? info, Style? warning, Style? error, Style? critical})
const

Properties

critical Style
final
debug Style
final
error Style
final
hashCode int
The hash code for this object.
no setterinherited
info Style
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose Style
final
warning Style
final

Methods

collectLoggableData(LoggableData data) → void
Метод должен заполнить data описанием исследуемого класса.
override
copyWith({Style? verbose, Style? debug, Style? info, Style? warning, Style? error, Style? critical}) LogStyles
logClassInfo() LoggableData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int level) Style

Constants

noColors → const LogStyles
terminalColors → const LogStyles