NullFormatter class final

Implemented types
Mixed-in types

Constructors

NullFormatter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(LogTheme theme, String text) String
override
collectLoggableData(LoggableData data) → void
Метод должен заполнить data описанием исследуемого класса.
override
logClassInfo() LoggableData
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited