Prop<T extends Object?> class final

Implementers

Properties

config LoggableConfig
final
hashCode int
The hash code for this object.
no setterinherited
hidden bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showName bool
final
value → T
final
view Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLogString({LogTheme theme = LogTheme.noColors, int depth = 0, LoggableConfig config = const LoggableConfig(), Object? sanitized = _notSanitized}) String
toMapEntry({LoggableJsonConfig config = const LoggableJsonConfig(), Object? sanitized = _notSanitized}) MapEntry<String, Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

noView → const LoggableNoView