TypeProp class final

Inheritance

Properties

config LoggableConfig
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBrackets bool
final
showName bool
finalinherited
typeName String?
final
value Type
finalinherited
view Object?
finalinherited

Methods

copyWith({String? name, bool? showName, bool? showBrackets}) TypeProp
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLogString({LogTheme theme = LogTheme.noColors, int depth = 0, LoggableConfig config = const LoggableConfig()}) String
inherited
toMapEntry({LoggableJsonConfig config = const LoggableJsonConfig()}) MapEntry<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited