metaKey constant
String
const metaKey
The key of the metadata line written as the first line of every chunk.
Implementation
static const String metaKey = ':meta';
The key of the metadata line written as the first line of every chunk.
static const String metaKey = ':meta';