FileLogSession class final
A single log session: an ordered chain of chunk files.
Properties
-
files
→ List<
File> -
Chunk files in ascending index order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- lastModified → DateTime
-
Last activity at the moment of
list().final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Total size in bytes at the moment of
list().final
Methods
-
delete(
) → Future< void> - Deletes all chunk files of this session.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Stream< List< int> > - The whole session as a byte stream: chunks concatenated in order, meta lines of chunks after the first are skipped.
-
readAsString(
) → Future< String> - The whole session as a string (see read).
-
readMeta(
) → Future< Map< String, Object?> > - The content of the session meta line, or an empty map if absent.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited