read method
The whole session as a byte stream: chunks concatenated in order, meta lines of chunks after the first are skipped. Non-regular entries that replace a chunk after listing are ignored.
Implementation
Stream<List<int>> read() async* {
var first = true;
for (final file in files) {
if (!_isRegularFile(file)) continue;
if (first) {
first = false;
yield* file.openRead();
} else {
yield* _skipMetaLine(file);
}
}
}