maxChunkSize property

int maxChunkSize
final

Rotation-size target for one chunk file, in bytes.

When a chunk reaches it, the next chunk is started. One JSON Lines record is never split, so it can make a chunk exceed this target. Must fit into maxSessionSize at least twice.

Implementation

final int maxChunkSize;