maxTotalSize property

int? maxTotalSize
final

Startup retention budget for all sessions together, in bytes.

This is not a hard runtime ceiling because the current session can exceed maxSessionSize. null disables this cleanup.

Implementation

final int? maxTotalSize;