ready property

Future<void> ready
latefinal

Completes when the storage is initialized: the directory is created, old sessions are cleaned up, the session id is resolved and the first chunk with the metadata line is reserved on disk. Never completes with an error. Awaiting it is optional: logs published earlier are buffered.

Implementation

late final Future<void> ready;