sessionId property

String get sessionId

The id of the current session.

May get a numeric suffix during initialization if a session with the same id already exists on disk (see ready).

Implementation

String get sessionId => _sessionId;