handle abstract method
Processes a single log event with its bound parameter.
Events are processed strictly sequentially: the next event is not handled until the future returned by this method completes.
Implementation
FutureOr<void> handle(Param param, Log log);