LazyStringOrNull class final
Class for lazy evaluation of a string value or null.
Same as Lazy, but with subsequent conversion of Object to String
using the toString method. The null value is returned as is.
Constructors
- LazyStringOrNull(Object? unresolved)
- Creates a lazy nullable string from a direct value or a function computing it.
- LazyStringOrNull.resolved(String? resolved)
- Creates a lazy nullable string from an already resolved value.
Properties
Methods
-
convert(
Object? resolved) → String? -
Converts a
resolvedvalue whose type does not matchT.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited