LogConstraints class sealed
Constructors
- LogConstraints({int min, int? max})
-
constfactory
- LogConstraints.exact(int size)
-
constfactory
- LogConstraints.growable({int initial, int? max})
-
factory
- LogConstraints.unlimited()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGrowable → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
int value) → int -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
restrict(
int? max) → LogConstraints -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited