LogRow class final
One output row of ConsoleLogPrinter: children form the body,
tail is right-aligned (typically tags). maxLength limits the width
(long content wraps or truncates), maxLines limits the height,
when makes the row conditional.
Constructors
-
LogRow({required List<
LogBlock> children, List<LogBlock> tail = const [], required int maxLength, int? maxLines, bool when(Log log)?, LogDivider defaultDivider = const LogDivider(' '), bool alignTail = true}) -
const
-
LogRow.singleLine({required List<
LogBlock> children, List<LogBlock> tail = const [], bool when(Log log)?, LogDivider defaultDivider = const LogDivider(' '), bool alignTail = true}) -
const
Properties
- alignTail → bool
-
final
-
children
→ List<
LogBlock> -
final
- defaultDivider → LogDivider
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int?
-
final
- maxLines → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleLine → bool
-
no setter
-
tail
→ List<
LogBlock> -
final
- when → bool Function(Log log)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited