LoggableMultiData class final
Constructors
-
LoggableMultiData(Map<
String, Object?> data, {LoggableConfig config = const LoggableConfig()})
Properties
- config → LoggableConfig
-
final
-
data
→ Map<
String, Object?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool wrapLines = false, String keyFormatter(String key)?, String valueFormatter(String key)?}) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited