Base class for lazy evaluation of a typed value.
Same as Lazy, but with subsequent conversion of Object? to T
using the convert method.
If the value already has type T, the convert method will not be called!
Constructors
- TypedLazy(Object? unresolved)
- Creates a lazy typed value from a direct value or a function computing it.
- TypedLazy.resolved(T resolved)
-
Creates a lazy typed value from an already resolved value of type
T.
Properties
Methods
-
convert(
Object? resolved) → T -
Converts a
resolvedvalue whose type does not matchT. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited