FileLogCodec class final
Encodes Logs and session metadata as JSON Lines.
Constructors
- FileLogCodec({FileLogDataFormat dataFormat = FileLogDataFormat.text, LogMainTheme? theme, LoggableConfig config = const LoggableConfig(), LoggableJsonConfig jsonConfig = const LoggableJsonConfig()})
Properties
- config → LoggableConfig
-
final
- dataFormat → FileLogDataFormat
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonConfig → LoggableJsonConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → LogMainTheme
-
final
Methods
-
encode(
Log log) → String -
Encodes
logas a single JSON line (no trailing newline). -
encodeMeta(
{required String sessionId, required DateTime started, Map< String, Object?> ? meta}) → String - Encodes the session metadata line (no trailing newline).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited