maxChunkSize property
Size limit of one chunk file, in bytes. When a chunk reaches it, the next chunk is started. Must fit into maxSessionSize at least twice.
Implementation
final int maxChunkSize;
Size limit of one chunk file, in bytes. When a chunk reaches it, the next chunk is started. Must fit into maxSessionSize at least twice.
final int maxChunkSize;