maxSessionSize property

int maxSessionSize
final

Retained-size target for one session, in bytes.

The newest chunk is always kept, so an oversized record can make the session exceed this target. See the class documentation.

Implementation

final int maxSessionSize;